@@ -23,7 +23,6 @@
 
 #include <config.h>
 #include <libanjuta/anjuta-shell.h>
-#include <libgnomevfs/gnome-vfs-utils.h>
 #include <glib/gi18n.h>
 #include <libanjuta/interfaces/ianjuta-document-manager.h>
 #include <libanjuta/interfaces/ianjuta-project-manager.h>
@@ -48,7 +47,7 @@ project_root_added (AnjutaPlugin *plugin, const gchar *name,
 	
 	if (root_uri)
 	{
-		gchar *root_dir = gnome_vfs_get_local_path_from_uri (root_uri);
+		gchar *root_dir = anjuta_util_get_local_path_from_uri (root_uri);
 		if (root_dir)
 		{	
 			ci_plugin->top_dir = g_strdup(root_dir);
@@ -75,7 +74,7 @@ project_root_removed (AnjutaPlugin *plugin, const gchar *name,
 	class_inheritance_clean_canvas (ci_plugin);
 
 	/* destroy and re-initialize the hashtable */
-	class_inheritance_hash_table_clear	(ci_plugin);
+	class_inheritance_gtree_clear (ci_plugin);
 	
 	if (ci_plugin->top_dir)
 		g_free(ci_plugin->top_dir);
@@ -103,7 +102,7 @@ activate_plugin (AnjutaPlugin *plugin)
 	AnjutaClassInheritance *class_inheritance;
 	static gboolean initialized = FALSE;
 	
-	DEBUG_PRINT ("AnjutaClassInheritance: Activating plugin ...");
+	DEBUG_PRINT ("%s", "AnjutaClassInheritance: Activating plugin ...");
 	
 	register_stock_icons (plugin);
 	
@@ -130,16 +129,16 @@ activate_plugin (AnjutaPlugin *plugin)
 static gboolean
 deactivate_plugin (AnjutaPlugin *plugin)
 {
-	DEBUG_PRINT ("AnjutaClassInheritance: Dectivating plugin ...");
+	DEBUG_PRINT ("%s", "AnjutaClassInheritance: Dectivating plugin ...");
 	AnjutaClassInheritance* class_inheritance;
 	class_inheritance = ANJUTA_PLUGIN_CLASS_INHERITANCE (plugin);
 
 	/* clean up the canvas [e.g. destroys it's elements */
 	class_inheritance_clean_canvas (class_inheritance);
 	
-	/* destroy the nodestatus hash table */
+	/* destroy the nodestatus gtree */
 	if (class_inheritance->expansion_node_list) {
-		g_hash_table_destroy (class_inheritance->expansion_node_list);
+		g_tree_destroy (class_inheritance->expansion_node_list);
 		class_inheritance->expansion_node_list = NULL;
 	}
 	
