@@ -18,10 +18,10 @@
  */
 
 #include "sourceview-io.h"
+#include "sourceview-private.h"
 #include <libanjuta/interfaces/ianjuta-editor.h>
 #include <libanjuta/anjuta-convert.h>
 #include <libanjuta/anjuta-encodings.h>
-#include <sourceview-private.h>
 
 #define READ_SIZE 4096
 #define RATE_LIMIT 5000 /* Use a big rate limit to avoid duplicates */
@@ -35,6 +35,7 @@ enum
 	OPEN_FINISHED,
 	OPEN_FAILED,
 	SAVE_FAILED,
+	FILE_DELETED,
 
 	LAST_SIGNAL
 };
@@ -85,6 +86,7 @@ sourceview_io_class_init (SourceviewIOClass *klass)
 	object_class->finalize = sourceview_io_finalize;
 
 	klass->changed = NULL;
+	klass->deleted = NULL;
 	klass->save_finished = NULL;
 	klass->open_finished = NULL;
 	klass->open_failed = NULL;
@@ -139,6 +141,16 @@ sourceview_io_class_init (SourceviewIOClass *klass)
 		              g_cclosure_marshal_VOID__POINTER,
 		              G_TYPE_NONE, 1,
 		              G_TYPE_POINTER);
+	
+	io_signals[FILE_DELETED] =
+		g_signal_new ("deleted",
+		              G_OBJECT_CLASS_TYPE (klass),
+		              0,
+		              G_STRUCT_OFFSET (SourceviewIOClass, deleted),
+		              NULL, NULL,
+		              g_cclosure_marshal_VOID__VOID,
+		              G_TYPE_NONE, 0,
+		              NULL);
 }
 
 static void on_file_changed (GFileMonitor* monitor, 
@@ -149,7 +161,18 @@ static void on_file_changed (GFileMonitor* monitor,
 {
 	SourceviewIO* sio = SOURCEVIEW_IO(data);
 	
-	g_signal_emit_by_name (sio, "changed");
+	switch (event_type)
+	{
+		case G_FILE_MONITOR_EVENT_CREATED:
+		case G_FILE_MONITOR_EVENT_CHANGES_DONE_HINT:
+			g_signal_emit_by_name (sio, "changed");
+			break;
+		case G_FILE_MONITOR_EVENT_DELETED:
+			g_signal_emit_by_name (sio, "deleted");
+			break;
+		default:
+			break;
+	}
 }
 
 static gboolean
@@ -220,6 +243,8 @@ on_save_finished (GObject* output_stream, GAsyncResult* result, gpointer data)
 	g_output_stream_write_finish (G_OUTPUT_STREAM(output_stream),
 								  result,
 								  &err);
+	g_free (sio->write_buffer);
+	sio->write_buffer = NULL;
 	if (err)
 	{
 		g_signal_emit_by_name (sio, "save-failed", err);
@@ -229,11 +254,9 @@ on_save_finished (GObject* output_stream, GAsyncResult* result, gpointer data)
 	{
 		set_display_name (sio);
 		g_output_stream_close(G_OUTPUT_STREAM (output_stream), NULL, NULL);
-		g_signal_emit_by_name (sio, "save-finished");
 		setup_monitor (sio);
+		g_signal_emit_by_name (sio, "save-finished");
 	}
-	g_free (sio->write_buffer);
-	sio->write_buffer = NULL;
 	g_object_unref (output_stream);
 }
 
@@ -257,30 +280,22 @@ sourceview_io_save_as (SourceviewIO* sio, GFile* file)
 {
 	GFileOutputStream* output_stream;
 	GError* err = NULL;
+	gboolean backup = TRUE;
+	
 	g_return_if_fail (file != NULL);
 	
 	cancel_monitor (sio);
 	
-	output_stream = g_file_create (file, G_FILE_CREATE_NONE, NULL, &err);
+	backup = anjuta_preferences_get_int_with_default (sio->sv->priv->prefs,
+													  "sourceview.backup", TRUE);
+	
+	output_stream = g_file_replace (file, NULL, backup, G_FILE_CREATE_NONE,
+									NULL, NULL);
 	if (!output_stream)
 	{
-		if (err->code != G_IO_ERROR_EXISTS)
-		{
-			g_signal_emit_by_name (sio, "save-failed", err);
-			g_error_free (err);
-			return;
-		}
-		else
-		{
-			output_stream = g_file_replace (file, NULL, TRUE, G_FILE_CREATE_NONE,
-											NULL, NULL);
-			if (!output_stream)
-			{
-				g_signal_emit_by_name (sio, "save-failed", err);
-				g_error_free (err);
-				return;
-			}
-		}
+		g_signal_emit_by_name (sio, "save-failed", err);
+		g_error_free (err);
+		return;
 	}
 	
 	if (sio->last_encoding == NULL)
