@@ -224,13 +224,13 @@ sourceview_set_message_area (Sourceview* sv,  GtkWidget *message_area)
 /* Callbacks */
 
 static void
-on_assist_window_destroyed (AssistWindow* window, Sourceview* sv)
+on_assist_window_destroyed (Sourceview* sv, gpointer where_object_was)
 {
 	sv->priv->assist_win = NULL;
 }
 
 static void 
-on_assist_tip_destroyed (AssistTip* tip, Sourceview* sv)
+on_assist_tip_destroyed (Sourceview* sv, gpointer where_object_was)
 {
 	sv->priv->assist_tip = NULL;
 }
@@ -489,7 +489,7 @@ on_open_finish(SourceviewIO* io, Sourceview* sv)
 	if (sourceview_io_get_read_only (io))
 	{
 		gchar* filename = sourceview_io_get_filename (io);
-		gchar* buff = g_strdup_printf ("The file '%s' is read-only! Edit anyway?",
+		gchar* buff = g_strdup_printf (_("The file '%s' is read-only! Edit anyway?"),
 									   filename);
 		GtkWidget* message_area;
 		g_free (filename);
@@ -983,7 +983,7 @@ static gint ieditor_get_lineno(IAnjutaEditor *editor, GError **e)
 static gint ieditor_get_length(IAnjutaEditor *editor, GError **e)
 {
 	/* We do not use gtk_text_buffer_get_char_count here because
-	someone may rely that this is the size of a buffer for all the text */
+	 we need a size in bytes not in characters */
 	
 	GtkTextIter start_iter;
 	GtkTextIter end_iter;
@@ -997,7 +997,7 @@ static gint ieditor_get_length(IAnjutaEditor *editor, GError **e)
 								   &end_iter);
 	text = gtk_text_buffer_get_slice(GTK_TEXT_BUFFER(sv->priv->document),
 									&start_iter, &end_iter, TRUE);
-	length = g_utf8_strlen(text,  -1);
+	length = strlen(text);
 	g_free(text);
 
 	return length;
@@ -1887,15 +1887,17 @@ ilanguage_get_supported_languages (IAnjutaEditorLanguage *ilanguage,
 	static GList* languages = NULL;
 	if (!languages)
 	{
-		GStrv langs;
-		GStrv lang;
-		g_object_get (gtk_source_language_manager_get_default(), "language-ids", &langs, NULL);
-		
-		for (lang = langs; *lang != NULL; lang++)
+		const gchar* const * langs = gtk_source_language_manager_get_language_ids (gtk_source_language_manager_get_default());		
+		if (langs)
 		{
-			languages = g_list_append (languages, *lang);
+			const gchar* const * lang;
+		
+			for (lang = langs; *lang != NULL; lang++)
+			{
+				languages = g_list_append (languages, (gpointer)*lang);
+			}
 		}
-	}		
+	}
 	return languages;
 }
 
@@ -1937,15 +1939,13 @@ ilanguage_set_language (IAnjutaEditorLanguage *ilanguage,
 {
 	Sourceview* sv = ANJUTA_SOURCEVIEW (ilanguage);
 	gboolean found = FALSE;
-	GStrv languages;
-	GStrv cur_lang;
-	g_object_get (G_OBJECT (gtk_source_language_manager_get_default ()), "language-ids",
-							&languages, NULL);
-	for (cur_lang = languages; *cur_lang != NULL && language != NULL; cur_lang++)
+	const GList* languages = ilanguage_get_supported_languages(ilanguage, err);
+	const GList* cur_lang;
+	for (cur_lang = languages; cur_lang != NULL && language != NULL; cur_lang = g_list_next (cur_lang))
 	{
 		GtkSourceLanguage* source_language = 
 			gtk_source_language_manager_get_language (gtk_source_language_manager_get_default(),
-													  *cur_lang);
+													  cur_lang->data);
 		const gchar* id = gtk_source_language_get_id (source_language);
 		
 		if (g_str_equal (language, id))
@@ -1958,7 +1958,6 @@ ilanguage_set_language (IAnjutaEditorLanguage *ilanguage,
 			break;
 		}
 	}
-	g_strfreev(languages);
 	if (!found)
 	{
 		autodetect_language (sv);
@@ -1973,7 +1972,7 @@ ilanguage_get_language (IAnjutaEditorLanguage *ilanguage, GError **err)
 	GtkSourceLanguage* lang = gtk_source_buffer_get_language(buffer);
 	if (lang)
 	{
-		return gtk_source_language_get_name(lang);
+		return gtk_source_language_get_id(lang);
 	}
 	else
 	{
@@ -2046,8 +2045,8 @@ iassist_suggest (IAnjutaEditorAssist *iassist, GList* choices, IAnjutaIterable*
 		{
 			sv->priv->assist_win = assist_window_new(GTK_TEXT_VIEW(sv->priv->view), NULL,
 													 ianjuta_iterable_get_position (ipos, NULL));
-			g_signal_connect(G_OBJECT(sv->priv->assist_win), "destroy", 
-								 G_CALLBACK(on_assist_window_destroyed), sv);
+			g_object_weak_ref (G_OBJECT(sv->priv->assist_win),
+			                   (GWeakNotify)on_assist_window_destroyed, sv);
 			g_signal_connect(G_OBJECT(sv->priv->assist_win), "chosen", 
 								 G_CALLBACK(on_assist_chosen), sv);
 			g_signal_connect(G_OBJECT(sv->priv->assist_win), "cancel", 
@@ -2101,8 +2100,9 @@ iassist_show_tips (IAnjutaEditorAssist *iassist, GList* tips, IAnjutaIterable* i
 		sv->priv->assist_tip = 
 			ASSIST_TIP (assist_tip_new (GTK_TEXT_VIEW (sv->priv->view), tips));
 		
-		g_signal_connect (G_OBJECT(sv->priv->assist_tip), "destroy", G_CALLBACK(on_assist_tip_destroyed),
-						  sv);
+		g_object_weak_ref (G_OBJECT(sv->priv->assist_tip),
+		                   (GWeakNotify) on_assist_tip_destroyed,
+		                   sv);
 		assist_tip_move (sv->priv->assist_tip, GTK_TEXT_VIEW (sv->priv->view), tip_position);
 		gtk_widget_show (GTK_WIDGET (sv->priv->assist_tip));
 	}
@@ -2235,6 +2235,7 @@ isearch_iface_init(IAnjutaEditorSearchIface* iface)
 }
 
 /* IAnjutaHover */
+static void on_sourceview_hover_destroy (gpointer data, GObject* where_the_data_was);
 static void
 on_sourceview_hover_leave(gpointer data, GObject* where_the_data_was)
 {
@@ -2246,8 +2247,16 @@ on_sourceview_hover_leave(gpointer data, GObject* where_the_data_was)
 		g_object_unref (sv->priv->tooltip_cell);
 		sv->priv->tooltip_cell = NULL;
 	}
+	g_object_weak_unref (G_OBJECT(sv), on_sourceview_hover_destroy, where_the_data_was);
 }
 
+static void
+on_sourceview_hover_destroy (gpointer data, GObject* where_the_data_was)
+{
+	g_object_weak_unref (G_OBJECT(data), on_sourceview_hover_leave, where_the_data_was);
+}
+
+
 static gboolean 
 on_sourceview_hover_over (GtkWidget *widget, gint x, gint y,
 						  gboolean keyboard_tip, GtkTooltip *tooltip,
@@ -2257,11 +2266,11 @@ on_sourceview_hover_over (GtkWidget *widget, gint x, gint y,
 	SourceviewCell* cell;
 	GtkTextIter iter;
 	GtkTextView *text_view = GTK_TEXT_VIEW (widget);
-	gint bx, by, trailing;
+	gint bx, by;
 		
 	gtk_text_view_window_to_buffer_coords (text_view, GTK_TEXT_WINDOW_TEXT,
 											   x, y, &bx, &by);
-	gtk_text_view_get_iter_at_position (text_view, &iter, &trailing, bx, by);
+	gtk_text_view_get_iter_at_location (text_view, &iter, bx, by);
 	
 	cell = sourceview_cell_new (&iter, text_view);
 	
@@ -2272,6 +2281,7 @@ on_sourceview_hover_over (GtkWidget *widget, gint x, gint y,
 	{
 		gtk_tooltip_set_text (tooltip, sv->priv->tooltip);
 		g_object_weak_ref (G_OBJECT (tooltip), on_sourceview_hover_leave, sv);
+		g_object_weak_ref (G_OBJECT (sv), on_sourceview_hover_destroy, tooltip);
 		g_free (sv->priv->tooltip);
 		sv->priv->tooltip = NULL;
 		sv->priv->tooltip_cell = cell;
