@@ -47,9 +47,10 @@
 #define THREADS_MAX_CONCURRENT			2
 #define TRIGGER_SIGNALS_DELAY			100
 
-#define MEMORY_POOL_STRING_SIZE			100
-#define MEMORY_POOL_INT_SIZE			100
+#define MEMORY_POOL_STRING_SIZE			200
+#define MEMORY_POOL_INT_SIZE			200
 
+#define DUMMY_VOID_STRING				""
 
 #define USE_ASYNC_QUEUE
 #undef USE_ASYNC_QUEUE
@@ -61,6 +62,7 @@
 /*		DEBUG_PRINT ("lend str %p, qlength %d [-]", OUT_gvalue, g_async_queue_length (sdb_priv->mem_pool_string));*/
 
 #define MP_RETURN_OBJ_STR(sdb_priv, gvalue) \
+	g_value_set_static_string (gvalue, DUMMY_VOID_STRING); \
 	g_async_queue_push(sdb_priv->mem_pool_string, gvalue); 
 /*	DEBUG_PRINT ("return str %p, qlength %d [+]", gvalue, g_async_queue_length (sdb_priv->mem_pool_string));*/
 
@@ -76,8 +78,11 @@
 		OUT_gvalue = (GValue*)g_queue_pop_head(sdb_priv->mem_pool_string); 
 
 #define MP_RETURN_OBJ_STR(sdb_priv, gvalue) \
+	g_value_set_static_string (gvalue, DUMMY_VOID_STRING); \
 	g_queue_push_head(sdb_priv->mem_pool_string, gvalue); 
 
+
+
 #define MP_LEND_OBJ_INT(sdb_priv, OUT_gvalue) \
 		OUT_gvalue = (GValue*)g_queue_pop_head(sdb_priv->mem_pool_int); 
 
@@ -183,6 +188,7 @@ typedef enum {
 	DYN_PREP_QUERY_GET_SYMBOL_INFO_BY_ID,
 	DYN_PREP_QUERY_FIND_SYMBOL_NAME_BY_PATTERN,
 	DYN_PREP_QUERY_FIND_SYMBOL_BY_NAME_PATTERN_FILTERED,
+	DYN_PREP_QUERY_FIND_SYMBOL_BY_NAME_PATTERN_FILE,
 	DYN_PREP_QUERY_GET_SCOPE_MEMBERS_BY_SYMBOL_ID,
 	DYN_PREP_QUERY_GET_SCOPE_MEMBERS_BY_SYMBOL_ID_FILTERED,
 	DYN_PREP_QUERY_GET_FILES_FOR_PROJECT,
